import * as React from 'react';
import {
  Button,
  Table,
  Label,
  Segment,
  Header,
  Container,
} from 'semantic-ui-react';
import Probe from '@overflow/probe/api/model/Probe';
import { Discovery } from '@overflow/discovery/react/components/Discovery';

import * as Utils from '@overflow/commons/util/Utils';

export interface StateProps {
  id: string;
  probe: Probe;
}

export interface DispatchProps {
  onRead?(id: string): void;
  onDiscoveryClick?(id:string):void;
}

export type Props = StateProps & DispatchProps;

export interface State {
}


export class ProbeDetailInfo extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
    };
  }

  public componentWillMount(): void {
    this.props.onRead(this.props.id);
  }

  public handleStartStop(event: any, data: any): void {
    console.log(event);
  }

  public handleDiscovery = (event: any, data: any): void => {
    this.props.onDiscoveryClick(this.props.id);
  }


  public showStopBtn(): JSX.Element {
    if (this.props.probe.status.name === 'NORMAL') {
      return <Button content='Stop' icon='stop' labelPosition='left' negative />;
    }
  }

  public render(): JSX.Element {
    if (this.props.probe === undefined) {
      return null;
    }
    return (
      <Container fluid>
        <Table celled={false} >
          <Table.Body>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Name</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.displayName}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Status</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.status.name}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Created at</Header>
              </Table.Cell>
              <Table.Cell>{Utils.date2date(this.props.probe.createDate)}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Authorized at</Header>
              </Table.Cell>
              <Table.Cell>{Utils.date2date(this.props.probe.authorizeDate)}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Authorized by</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.authorizeMember.name}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Uptime</Header>
              </Table.Cell>
              <Table.Cell>todo.</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Description</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.description}</Table.Cell>
            </Table.Row>
          </Table.Body>
        </Table>
        {this.showStopBtn()}
        <Button content='Discovery' icon='search' labelPosition='left' floated={'right'} positive onClick={this.handleDiscovery} />
        {/*{this.renderDiscovery()}*/}
      </Container>
    );
  }

}

